@@ -70,14 +70,14 @@ bool Kwave::UndoInsertAction::store(SignalManager &)
 Kwave::UndoAction *Kwave::UndoInsertAction::undo(
     Kwave::SignalManager &manager, bool with_redo)
 {
-    Kwave::UndoAction *redo_action = Q_NULLPTR;
+    Kwave::UndoAction *redo_action = nullptr;
 
     // store data for redo
     if (with_redo) {
         redo_action = new(std::nothrow) Kwave::UndoDeleteAction(
             m_parent_widget, m_track_list, m_offset, m_length);
         Q_ASSERT(redo_action);
-        if (!redo_action) return Q_NULLPTR;
+        if (!redo_action) return nullptr;
         redo_action->store(manager);
     }
 
@@ -105,3 +105,5 @@ void Kwave::UndoInsertAction::dump(const QString &indent)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_UndoInsertAction.cpp"
