@@ -27,7 +27,6 @@
 namespace Kwave
 {
 
-    class PluginContext;
 
     class InsertAtPlugin: public Kwave::GotoPluginBase
     {
@@ -42,15 +41,15 @@ namespace Kwave
         InsertAtPlugin(QObject *parent, const QVariantList &args);
 
         /** Destructor */
-        virtual ~InsertAtPlugin() Q_DECL_OVERRIDE;
+        ~InsertAtPlugin() override;
 
     protected:
 
         /** Returns the command to be emitted */
-        virtual QString command() const Q_DECL_OVERRIDE;
+        QString command() const override;
 
         /** Returns the title of the dialog */
-        virtual QString title() const Q_DECL_OVERRIDE;
+        QString title() const override;
 
     };
 }
